@@ -5,8 +5,7 @@ from pathlib import Path
 import jwt
 import pytz
 import requests
-
-from euskalmet.exceptions import EuskalmetException
+from exceptions import EuskalmetException
 
 # TODO: Introducir loggers
 
